//********************************************************************************//
// FILE:		zarIO.h
// PROJECT:		zarLib  - ver 1.00 -
// COPYRIGHTS:	The famous group 4 of "Roskilde Universites Center"
//********************************************************************************//
// Preprocessor:

/* Make sure this file is included only once: */
#ifndef _ZARIO_
#define _ZARIO_


//********************************************************************************
// Typedefs:

typedef struct
{
	FILE*	pFile;			// Pointer to the open file.
	_int  	nBitMask;		// The mask used by the library to get the bits (have to force int32)
	int 	nCurByte;		// The current read byte
	_dword  dwByteCount;	// The number of bytes read thus far
	_dword	dwFileSize;		// The size of the file
} ZAR_FILE;


//********************************************************************************
// Function prototypes:

// Load of files:
ZAR_FILE* zarLoadFile(_pcstr pFile, _pcstr pReadMode);
ZAR_FILE* zarLoadInputFile(_pcstr pFileName);
ZAR_FILE* zarLoadOutputFile(_pcstr pFileName, int nFlags);

// File name management:
int	 zarGetFileNameInPath(_pcstr pszSrc, _pstr pszDst);
void zarSetFileExtension(_pstr pszSrc);

// File info:
_dword zarFileSizeFromPath(_pcstr pszFile);
_dword zarFileSize(ZAR_FILE* pzFile);

// Close file:
void zarCloseFile(ZAR_FILE* pzarFile);
void zarFlushFileData(ZAR_FILE* pzFile);

// File header management:
int zarSaveFileHeader(const ZAR_FILE* pzFile, _ushort usInfo, _pcstr pFileName);
int zarLoadFileHeader(const ZAR_FILE* pzFile, _ushort* pusInfo, _pstr pFileName);



//********************************************************************************
// Function flags:

/* zarLoadOutputFile -> nFlags */
#define ZAR_ASK_IF_EXISTS			1		// Asks the user primission to override the file


//**********************************************************************************
// Function prototypes:

void   zarSetUpdateChunckF(_dword dwChunckSize);
void   zarSetByteF(const ZAR_FILE* pzDst, int nByte);
int    zarGetByteF(const ZAR_FILE* pzFile);
void   zarSetBitF(ZAR_FILE* pzFile, int nBit);
void   zarSetBitsF(ZAR_FILE* pzFile, _dword dwBits, int nBitCount);
void   zarSetBytesF(const ZAR_FILE* pzDst, _pstr pBytes, int nNumBytes);
int	   zarGetBitF(ZAR_FILE* pzFile);
_dword zarGetBitsF(ZAR_FILE* pzFile, int nNumBits);
_dword zarGetBytesF(const ZAR_FILE* pzSrc, void* pBuffer, int nNumBytes);


//********************************************************************************
// Inline functions:

// Include the inline functions, if this is a MS compatible compiler
#if _MSC_VER && _MSC_EXTENSIONS		

#include "zarIO.inl"

// Standard is to use the inline versions of the functions,
// to use the none-inline versions call the "F" functions:

#define zarSetUpdateChunck(a)		zarSetUpdateChunckI(a)
#define zarSetByte(a,b)				zarSetByteI(a,b)
#define zarGetByte(a)				zarGetByteI(a)
#define zarSetBit(a,b)				zarSetBitI(a,b)
#define zarSetBits(a,b,c)			zarSetBitsI(a,b,c)
#define zarSetBytes(a,b,c)			zarSetBytesI(a,b,c)
#define zarGetBit(a)				zarGetBitI(a)
#define zarGetBits(a,b)				zarGetBitsI(a,b)
#define zarGetBytes(a,b,c)			zarGetBytesI(a,b,c)

#else

// Standard is to use the real functions,
// beacuse this compiler doesnt support MS extensions

#define zarSetUpdateChunck(a)		zarSetUpdateChunckF(a)
#define zarSetByte(a,b)				zarSetByteF(a,b)
#define zarGetByte(a)				zarGetByteF(a)
#define zarSetBit(a,b)				zarSetBitF(a,b)
#define zarSetBits(a,b,c)			zarSetBitsF(a,b,c)
#define zarSetBytes(a,b,c)			zarSetBytesF(a,b,c)
#define zarGetBit(a)				zarGetBitF(a)
#define zarGetBits(a,b)				zarGetBitsF(a,b)
#define zarGetBytes(a,b,c)			zarGetBytesF(a,b,c)


#endif	// _MSC_VER && _MSC_EXTENSIONS

#endif	// _ZARIO_
