//********************************************************************************
// FILE:		zarLocal.c
// PROJECT:		zarLib  - ver 1.00 -
// COPYRIGHTS:	The famous group 4 of "Roskilde Universites Center"
//*********************************************************************************/

// Headers:
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
#include "zarLocal.h"

//********************************************************************************
// Globals:

extern const ZAR_INIT* g_pzarInit;


//********************************************************************************
// freeInitData() 


//********************************************************************************
// verifyArgs()

int processArgs(_pcstr* ppArgs, ZAR_TASK* pzTask)
{
	int i, j;
	
	// Zero data:
	memset(pzTask, 0, sizeof(ZAR_TASK));
		
	
	//---------------------------------//
	// Printing:
	//---------------------------------//
	
	// Should we print help?
	if (ppArgs[1] == NULL || (0 == strcmp(ppArgs[1], "/?")) || (0 == strcmp(ppArgs[1], "-?"))) 
	{
		zarPrintHelp();
		return 0;
	}

	// Print the header:
	zarPrintHeader();
	

	//---------------------------------//
	// Extract switches and commands:
	//---------------------------------//
	
	// Get commands:
	for (j=0; j<g_pzarInit->nNumCommands; j++)
	{
		// Search through the given commands and try to find a match:
		if (0 == strcmp(g_pzarInit->pCommands[j].szCmdArg, ppArgs[1]))
		{
			// Add the command:
			pzTask->dwCommand |= (1 << j);	// 2^j
			break;
		}
	}

	// Did we find any valid commands:
	if (pzTask->dwCommand == 0)
		return zarError(ERR_ARGS_WRONG_PARAMETER, ppArgs[1]);

	
	// Get switches:
	for (i=2; ppArgs[i]!=NULL; i++) 
	{
		// Is this a switch?
		if (ppArgs[i][0] == '-') 
		{
			// Go through all compression switches:
			for (j=0; j<g_pzarInit->nNumComSwitch; j++)
			{
				// Try to find a switch:
				if (0 == strcmp(g_pzarInit->pComSwitch[j].szSwitchArg, ppArgs[i] +1))
				{
					// Add the switch:
					pzTask->dwCompressSwitch |= (1 << j);	// 2^j
					break;
				}
			}
			
			// Go through all general switches:
			for (j=0; j<g_pzarInit->nNumGenSwitch; j++) 
			{
				// Try to find a switch:
				if (0 == strcmp(g_pzarInit->pGenSwitch[j].szSwitchArg, ppArgs[i] +1))
				{
					// Add the switch:
					pzTask->dwGeneralSwitch |= (1 << j);	// 2^j
					break;
				}
			}
		}
		
		// Then it must be a path:
		else
		{
			// Is it the source-path?
			if (pzTask->szSrc[0] == 0)
				strcpy(pzTask->szSrc, ppArgs[i]);
			else
			if (pzTask->szDst[0] == 0)
				strcpy(pzTask->szDst, ppArgs[i]);
			else
				return zarError(ERR_ARGS_WRONG_PARAMETER, ppArgs[i]);
		}
	}

	// Did we find any source files?
	if (pzTask->szSrc[0] == 0)
		return zarError(ERR_ARGS_NO_SOURCE_FILE, NULL);
	
	return 1;
}