//********************************************************************************//
// FILE:		zarTypes.h
// PROJECT:		zarLib  - ver 1.00 -
// COPYRIGHTS:	The famous group four of "Roskilde Universites Center"
//********************************************************************************//
// Preprocessor:

/* Make sure this file is included only once: */
#ifndef _ZARTYPES_
#define _ZARTYPES_


//********************************************************************************
// New primitive types:

// Is this a 16 bit cpu?
#ifdef ZAR_CPU_16

// 32 bit data types:
typedef unsigned long	_dword;
typedef long			_int;
typedef unsigned long	_uint;

// 16 bit data types:
typedef unsigned int	_ushort
typedef int				_short;


#else // This must be 32 or 64 bit

// 32 bit data types:
typedef unsigned int	_dword;
typedef int				_int;
typedef unsigned int	_uint;

// 16 bit data types:
typedef unsigned short	_ushort;
typedef short			_short;

#endif


// 8 bit data types:
typedef unsigned char  _ubyte;
typedef char		   _byte;


// Aliases for faster writing: 
typedef const char*	   _pcstr;
typedef char*		   _pstr;


//********************************************************************************
// New structs:

typedef struct
{
	_dword  dwCommand;
	_dword  dwGeneralSwitch;
	_dword  dwCompressSwitch;
	char    szSrc[_MAX_PATH +1];
	char    szDst[_MAX_PATH +1];
} ZAR_TASK;


typedef struct
{
	_pstr     pName;				// The name of the switch:			ex. "Dump time." 
	char	  szSwitchArg[3];		// The switch on the command-line:	ex. "t"
} ZAR_SWITCH;


typedef struct
{
	_pstr     pName;				// The name of the command:			ex. "Compress file."
	char	  szCmdArg[3];			// The command on the command-line: ex. "c" or ex. "ha"
} ZAR_COMMAND;

typedef struct
{
	_dword dwFlags;

	int (*compressMain)(ZAR_TASK*);	// Function pointer to main compression function
		
	int			 nNumCommands;	// Must be used or library will report error!
	ZAR_COMMAND* pCommands;
	  
	int			 nNumGenSwitch;	
	ZAR_SWITCH*	 pGenSwitch;	
		
	int			 nNumComSwitch;	
	ZAR_SWITCH*	 pComSwitch;	
	
} ZAR_INIT;


// Flags for ZAR_INIT::dwFlags:
#define ZAR_INIT_GENERAL_SWITCHES		1		// The nNumGenSwitch and pGenSwitch is valid! 
#define ZAR_INIT_COMPRESSION_SWITCHES	2		// The nNumComSwitch and pComSwitch is valid! 


#endif	// _ZARTYPES_


