//********************************************************************************
// FILE:		zarError.c
// PROJECT:		zarLib  - ver 1.00 -
// COPYRIGHTS:	The famous group 4 of "Roskilde Universites Center"
//*********************************************************************************/
// Headers:
#include <stdlib.h>
#include <stdio.h>
#include "zarLocal.h"


//********************************************************************************
// zarError()

int zarError(int nCode, const void* pData)
{
	switch (nCode)
	{
		case ERR_INPUT_FILE_NOT_READABLE:
			if (pData == NULL)
				printf("Error reading input file!\n");
			else
				printf("The file \"%s\" can not be opened!\n", (const char*) pData);
			return 0;

		case ERR_OUTPUT_FILE_NOT_WRITEABLE:
			if (pData == NULL)
				printf("The output file can not be accessed!\n");
			else	
				printf("The output file \"%s\" can not be accessed!\n", (const char*) pData);
			return 0;

		case ERR_OUTPUT_FILE_NOT_CREATEABLE:
			printf("The output file \"%s\" can not be created!\n", (const char*) pData);
			return 0;

		case ERR_INPUT_FILE_NOT_VALID_ZAR_FILE:
			printf("The input file is not a valid %s-file!\n", ZAR_PROGRAM_NAME);
			return 0;

		case ERR_ARGS_WRONG_PARAMETER:
			printf("Wrong parameter \"%s\"\n", (const char*) pData);
			return 0;

		case ERR_ARGS_NO_SOURCE_FILE:
			printf("The source-file is missing!\n");
			return 0;

		case ZAR_ERR_UNKNOWN_INTERNAL:
			printf("Unrecoverable internal error!\n");
			return 0;

		case ZAR_ERR_NOT_VALID_FILENAME:
			printf("\"%s\" is not a valid filename", (const char*) pData);
			return 0;

		case ZAR_ERR_WRONG_ZAR_VERSION:
			if (pData == NULL)
				printf("This program is too old to handle the compressed file!\n");
			else
				printf("This program is too old to handle \"%s\", please update to a newer version!\n", (const char*) pData);
			return 0;
		
		case ZAR_ERR_FILE_SEEK:
			printf("The file \"%s\" can not be searched: File corrupted!\n", (const char*) pData);
			return 0;

		case ZAR_ERR_FEATURE_NOT_IMPLEMENTED:
			printf("The %s is currently not implemented!\n", (const char*) pData);
			return 0;

		case ZAR_ERR_FAILED_MEMORY_ALLOC:
			printf("Couldnt allocate the needed memory!\n");
			return 0;

		case ZAR_ERR_MESSAGE:
			printf("%s\n", (const char*) pData);
			return 0;
	}

	return 0;
}
