//********************************************************************************//
// FILE:		zarIO.inl
// PROJECT:		zarLib  - ver 1.00 -
// COPYRIGHTS:	The famous group 4 of "Roskilde Universites Center"
//********************************************************************************//
// Preprocessor:

// Make sure this is a MS compatible compiler:
#if _MSC_VER && _MSC_EXTENSIONS

/* Make sure this file is included only once: */
#ifndef _ZARIO_INLINE_
#define _ZARIO_INLINE_


// Disable some warnings:
#pragma warning(disable : 4514)


//********************************************************************************
// Globals:

extern _dword g_dwUpdateChunck;


//********************************************************************************
// zarGetBitsI()

__inline _int zarGetBitsI(ZAR_FILE* pzFile, int nNumBits)
{
	_dword dwRet = 0;
	_dword dwMask = 1L << (nNumBits -1);

	while (dwMask != 0)
	{
		// Should we get a new byte?
		if (pzFile->nBitMask == 0)
		{	
			// Read a byte:
			pzFile->nCurByte = fgetc(pzFile->pFile);

			if (pzFile->nCurByte == EOF)
				return EOF;

			pzFile->dwByteCount++;

			if ((pzFile->dwByteCount % g_dwUpdateChunck) == 0)
				printf("*");
		
			// Update mask to extract the first bit:
			pzFile->nBitMask = 0x80;
		}

		if (pzFile->nCurByte & pzFile->nBitMask)
			dwRet |= dwMask;

		// Update masks:
		dwMask >>= 1;
		pzFile->nBitMask >>= 1;
	}

	return dwRet;
}


//********************************************************************************
// zarSetBitsI()

__inline void zarSetBitsI(ZAR_FILE* pzFile, _dword dwBits, int nNumBits)
{
	_dword dwMask = 1L << (nNumBits -1);

	while (dwMask != 0)
	{
		// Add a one?
		if (dwMask & dwBits)
			pzFile->nCurByte |= pzFile->nBitMask;

		// Update mask:
		pzFile->nBitMask >>= 1;

		// Should we store the data:
		if (pzFile->nBitMask == 0)
		{
			fputc(pzFile->nCurByte, pzFile->pFile);
		
			// Save the byte:
			pzFile->dwByteCount++;

			if ((pzFile->dwByteCount % g_dwUpdateChunck) == 0)
				printf("*");

			// Update:
			pzFile->nBitMask = 0x80;
			pzFile->nCurByte = 0;
		}

		dwMask >>= 1;
	}
}

//********************************************************************************
// zarGetBitI()

__inline int zarGetBitI(ZAR_FILE* pzFile)
{
	int nVal;
	
	// Should we read a new byte?
	if (pzFile->nBitMask == 0)
	{
		// Read a byte:
		pzFile->nCurByte = fgetc(pzFile->pFile);
		pzFile->dwByteCount++;

		if ((pzFile->dwByteCount % g_dwUpdateChunck) == 0)
			printf("*");
		
		// Update mask to extract the first bit:
		pzFile->nBitMask = 0x80;
	}

	// Update the mask to extract the next bit:
	nVal = pzFile->nBitMask;
	pzFile->nBitMask >>= 1;

	return (pzFile->nCurByte & nVal);
}


//********************************************************************************
// zarSetBitI()

__inline void zarSetBitI(ZAR_FILE* pzFile, int bit)
{
	if (bit)
		pzFile->nCurByte |= pzFile->nBitMask;
		
	
	// Update mask to next bit:
	pzFile->nBitMask >>= 1;	
	
	
	// Should we store the data:
	if (pzFile->nBitMask == 0)
	{
		fputc(pzFile->nCurByte, pzFile->pFile);
		
		// Save the byte:
		pzFile->dwByteCount++;

		if ((pzFile->dwByteCount % g_dwUpdateChunck) == 0)
			printf("*");

		// Update:
		pzFile->nBitMask = 0x80;
		pzFile->nCurByte = 0;
	}
}


//********************************************************************************
// zarGetNextByteI()

__inline int zarGetByteI(const ZAR_FILE* pzFile)
{
	return fgetc(pzFile->pFile);
}


//********************************************************************************
// zarSetByteI()

__inline void zarSetByteI(const ZAR_FILE* pzDst, int nByte)
{
	fputc(nByte, pzDst->pFile);
}


//********************************************************************************
// zarSetUpdateChunckI()

__inline void zarSetUpdateChunckI(_dword dwChunckSize)
{
	g_dwUpdateChunck = dwChunckSize;

	if (g_dwUpdateChunck == 0)	// the library could crash, if g_dwUpdateChunck == 0!
		g_dwUpdateChunck = 0xffffffff;
}


//********************************************************************************
// zarSetBytesI()

__inline void zarSetBytesI(const ZAR_FILE* pzDst, _pstr pBytes, int nNumBytes)
{
	fwrite(pBytes, sizeof(char), nNumBytes, pzDst->pFile);
}


//**********************************************************************************
// zarGetBytesI()

__inline _dword zarGetBytesI(const ZAR_FILE* pzSrc, void* pBuffer, int nNumBytes)
{
	return fread(pBuffer, sizeof(_byte), nNumBytes, pzSrc->pFile);
}

#endif // _MSC_VER && _MSC_EXTENSIONS

#endif // _ZARIO_INLINE_





